from .clipboardhist import ClipboardHist

__version__ = "1.0.1"
__author__ = "Hiro Takagi"
__email__ = "s2222103@stu.musashino-u.ac.jp"
__description__ = "A simple clipboard history management tool"

__all__ = ["ClipboardHist"]
